braindecode.datautil.create_windows_from_events
===============================================

.. currentmodule:: braindecode.datautil

.. autofunction:: create_windows_from_events

.. include:: braindecode.datautil.create_windows_from_events.examples

.. raw:: html

    <div style='clear:both'></div>